Enum deflate::MatchingType [−][src]
pub enum MatchingType {
Greedy,
Lazy,
}An enum describing whether we use lazy or greedy matching.
Variants
GreedyUse greedy matching: the matching algorithm simply uses a match right away if found.
LazyUse lazy matching: after finding a match, the next input byte is checked, to see if there is a better match starting at that byte.
As a special case, if max_hash_checks is set to 0, compression using only run-length (i.e maximum match distance of 1) is performed instead.